#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <string>
#include <string.h>

#include "TTree.h"
#include "TFile.h"
#include "TString.h"

#include "TSystem.h"
#include "TH1.h"
#include "TH2.h"
#include "TH3.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TChain.h"
#include "TEllipse.h"
#include "TLine.h"
#include "TMarker.h"
#include "TVector3.h"
#include "TRotation.h"
#include "TMath.h"
#include "TROOT.h"
#include "TF1.h"
#include "TGraph.h"
#include "TGraphErrors.h"
#include "TLatex.h" 
#include "TPolyLine.h" 


#define DEUTERON_MASS 1.875614
#define PROTON_MASS 0.93827
#define RAD2DEG 57.295779
#define DEG2RAD 0.017453293

using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(1111);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);


  gStyle->SetOptStat(1111);

}


void p0(){

  HallA_style();
  
  Double_t L_gold_p;
  Double_t L_gold_dp;

  

  TChain *t1 =new TChain("T");

  TString filename = Form("./PROJEKT/1456/projekt1456.root");
  t1->Add(filename.Data());
  filename = Form("./PROJEKT/1456/projekt1456_1.root");
  t1->Add(filename.Data());

  assert(t1);
  TChain *t2 =new TChain("T");

  filename = Form("./PROJEKT/1456/projekt1456.root");
  t2->Add(filename.Data());
  filename = Form("./PROJEKT/1456/projekt1456_1.root");
  t2->Add(filename.Data());

  assert(t2);
  
//############################ VARIABLES ############################

  t1->SetBranchAddress( "L.gold.p", &L_gold_p);
  t2->SetBranchAddress( "L.gold.dp", &L_gold_dp);
//############################ Histograms ############################


  TH1F *h1 = new TH1F("h1","h1",200,1.225,1.236);
  TH1F *h2 = new TH1F("h2","h2",200,-0.014,0);
 

//############################ Analysis p ############################

  int num = t1->GetEntries();
  num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t1->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h1->Fill(L_gold_p);  

  }

  delete t1; t1=NULL;

	
//############################ Analysis dp ############################

  num = t2->GetEntries();
  num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t2->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h2->Fill(L_gold_dp);  

  }

  delete t2; t2=NULL;
//########################### OUTPUTFILE###############
	TString filename3=Form("~/PROJEKT/HIST/1456.root");
	TFile *OutputRoot = new TFile( filename3.Data(), "RECREATE");
	h1->Write();
	h2->Write();
	delete OutputRoot; OutputRoot=NULL;

  //--- Canvas C0
  TCanvas *c0 = new TCanvas("c0","Energije sipanih elektronov",1000,1000);
  c0->Divide(2,2);
  c0->cd(1);
  h1->Draw();
  h1->GetXaxis()->SetTitle("p [GeV/c]");
  h1->SetTitle("P");
  //...TLine
  TLine *b1 = new TLine(1.23898, 0 ,1.23898, 850);
  b1->SetLineColor(kRed);
  b1->Draw("same");
  TLine *b2 = new TLine(1.2345411, 0 ,1.2345411, 850);
  b2->SetLineColor(kRed);
  b2->Draw("same");
  TLine *b3 = new TLine(1.2313258, 0 ,1.2313258, 850);
  b3->SetLineColor(kRed);
  b3->Draw("same");
  TLine *b4 = new TLine(1.229339, 0 ,1.229339, 850);
  b4->SetLineColor(kRed);
  b4->Draw("same");
  TLine *b5 = new TLine(1.228136, 0 ,1.228136, 850);
  b5->SetLineColor(kRed);
  b5->Draw("same");
  TLine *b6 = new TLine(1.22627, 0 ,1.22627, 850);
  b6->SetLineColor(kRed);
  b6->Draw("same");
  TLine *b7 = new TLine(1.224897, 0 ,1.224897, 850);
  b7->SetLineColor(kRed);
  b7->Draw("same");
  TLine *b8 = new TLine(1.22354, 0 ,1.22354, 850);
  b8->SetLineColor(kRed);
  b8->Draw("same");
  TLine *b9 = new TLine(1.22175, 0 ,1.22175, 850);
  b9->SetLineColor(kRed);
  b9->Draw("same");
//##########fitting
  Double_t par1[6];

  TF1 *g1    = new TF1("g1","gaus",1.2285,1.23);
  h1->Fit(g1,"R");
  TF1 *g2    = new TF1("g2","gaus",1.2337,1.2349);
  h1->Fit(g2,"R+");

  g1->GetParameters(&par1[0]);
  g2->GetParameters(&par1[3]);


//dp

  c0->cd(2);
  h2->Draw();
  h2->GetXaxis()->SetTitle("p [GeV/c]");
  h2->SetTitle("DP");

//##########fitting
  Double_t par2[6];

  TF1 *g3    = new TF1("g3","gaus",-0.0078,-0.0066);
  h2->Fit(g3,"R");
  TF1 *g4    = new TF1("g4","gaus",-0.0038,-0.0022);
  h2->Fit(g4,"R+");
//###########################NAREDI PREMICO IZ PARAMETROU
	double chisq1=g1->GetChisquare();
	double ndf1=g1->GetNDF();
	double chisqdf1=chisq1/ndf1;
	cout << "Chisquare: " << chisq1 << "/" << ndf1 << " : " << chisqdf1 << endl;
	double chisq2=g2->GetChisquare();
	double ndf2=g2->GetNDF();
	double chisqdf2=chisq2/ndf2;
	cout << "Chisquare: " << chisq2 << "/" << ndf2 << " : " << chisqdf2 << endl;
	double chisq3=g3->GetChisquare();
	double ndf3=g3->GetNDF();
	double chisqdf3=chisq3/ndf3;
	cout << "Chisquare: " << chisq3 << "/" << ndf3 << " : " << chisqdf3 << endl;
	double chisq4=g4->GetChisquare();
	double ndf4=g4->GetNDF();
	double chisqdf4=chisq4/ndf4;
	cout << "Chisquare: " << chisq4 << "/" << ndf4 << " : " << chisqdf4 << endl;

 	c0->cd(3);

   
  	Double_t mean1 = g1->GetParameter(1); 
	Double_t emean1 = g1->GetParError(1); 
	Double_t mean2 = g2->GetParameter(1); 
	Double_t emean2 = g2->GetParError(1); 

	Double_t mean3 = g3->GetParameter(1); 
	Double_t emean3 = g3->GetParError(1); 
	Double_t mean4 = g4->GetParameter(1); 
	Double_t emean4 = g4->GetParError(1); 
	
	 // Double_t mean1=1, mean2=2, mean3=3, mean4=4, emean1=1, emean2=2, emean3=3, emean4=4 ;
  	Double_t x[2] = {mean1, mean2};
  	Double_t y[2] = {mean3, mean4};
  	Double_t ex[2] = {emean1, emean2};
  	Double_t ey[2] = {emean3, emean4};

 	TGraphErrors *graf= new TGraphErrors(2,x,y,ex,ey);
  	graf->SetMarkerStyle(20);
  	graf->SetMarkerColor(kRed);
  	graf->Draw("AP");
   
}




