#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <string>
#include <string.h>

#include "TTree.h"
#include "TFile.h"
#include "TString.h"

#include "TSystem.h"
#include "TH1.h"
#include "TH2.h"
#include "TH3.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TChain.h"
#include "TEllipse.h"
#include "TLine.h"
#include "TMarker.h"
#include "TVector3.h"
#include "TRotation.h"
#include "TMath.h"
#include "TROOT.h"
#include "TF1.h"
#include "TGraph.h"
#include "TGraphErrors.h"
#include "TLatex.h" 
#include "TPolyLine.h" 


#define DEUTERON_MASS 1.875614
#define PROTON_MASS 0.93827
#define RAD2DEG 57.295779
#define DEG2RAD 0.017453293

using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(1111);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);


  gStyle->SetOptStat(1111);

}


void grafi1461(){

  HallA_style();
  
  Double_t L_gold_p;
  Double_t L_gold_ph; 
  Double_t L_gold_th;
  Double_t L_gold_dp;

  

  TChain *t1 =new TChain("T");

  TString filename = Form("./PROJEKT/1461/projekt1461.root");
  t1->Add(filename.Data());
  filename = Form("./PROJEKT/1461/projekt1461_1.root");
  t1->Add(filename.Data());

  assert(t1);
  TChain *t2 =new TChain("T");

  TString filename = Form("./PROJEKT/1461/projekt1461.root");
  t2->Add(filename.Data());
  filename = Form("./PROJEKT/1461/projekt1461_1.root");
  t2->Add(filename.Data());

  assert(t2);
  TChain *t3 =new TChain("T");

  TString filename = Form("./PROJEKT/1461/projekt1461.root");
  t3->Add(filename.Data());
  filename = Form("./PROJEKT/1461/projekt1461_1.root");
  t3->Add(filename.Data());

  assert(t3);
  TChain *t4 =new TChain("T");

  TString filename = Form("./PROJEKT/1461/projekt1461.root");
  t4->Add(filename.Data());
  filename = Form("./PROJEKT/1461/projekt1461_1.root");
  t4->Add(filename.Data());

  assert(t4);




//############################ VARIABLES ############################

  t1->SetBranchAddress( "L.gold.p", &L_gold_p);
  t2->SetBranchAddress( "L.gold.ph", &L_gold_ph);
  t3->SetBranchAddress( "L.gold.th", &L_gold_th);
  t4->SetBranchAddress( "L.gold.dp", &L_gold_dp);
//############################ Histograms ############################


  TH1F *h1 = new TH1F("h1","h1",200,1.22,1.24);
  TH1F *h2 = new TH1F("h2","h2",200,0,0.04);
  TH1F *h3 = new TH1F("h3","h3",200,0,0.1);
  TH1F *h4 = new TH1F("h4","h4",200,0,0.04);
 

//############################ Analysis p ############################

  int num = t1->GetEntries();
  //num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t1->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h1->Fill(L_gold_p);  

  }

  delete t1; t1=NULL;

//############################ Analysis ph ############################

  int num = t2->GetEntries();
  //num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t2->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h2->Fill(L_gold_ph);  

  }

  delete t2; t2=NULL;

//############################ Analysis th ############################

  int num = t3->GetEntries();
  //num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t3->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h3->Fill(L_gold_th);  

  }

  delete t3; t3=NULL;

//############################ Analysis dp ############################

  int num = t4->GetEntries();
  //num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t4->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h4->Fill(L_gold_p);  

  }

  delete t4; t4=NULL;


  //--- Canvas C0
  TCanvas *c0 = new TCanvas("c0","Energije sipanih elektronov",1000,1000);
  c0->Divide(2,2);
  c0->cd(1);
  h1->Draw();
  h1->GetXaxis()->SetTitle("p [GeV/c]");
  h1->SetTitle("P");
  //...TLine
  TLine *b1 = new TLine(1.23898, 0 ,1.23898, 850);
  b1->SetLineColor(kRed);
  b1->Draw("same");
  TLine *b2 = new TLine(1.2345411, 0 ,1.2345411, 850);
  b2->SetLineColor(kRed);
  b2->Draw("same");
  TLine *b3 = new TLine(1.2313258, 0 ,1.2313258, 850);
  b3->SetLineColor(kRed);
  b3->Draw("same");
  TLine *b4 = new TLine(1.229339, 0 ,1.229339, 850);
  b4->SetLineColor(kRed);
  b4->Draw("same");
  TLine *b5 = new TLine(1.228136, 0 ,1.228136, 850);
  b5->SetLineColor(kRed);
  b5->Draw("same");
  TLine *b6 = new TLine(1.22627, 0 ,1.22627, 850);
  b6->SetLineColor(kRed);
  b6->Draw("same");
  TLine *b7 = new TLine(1.224897, 0 ,1.224897, 850);
  b7->SetLineColor(kRed);
  b7->Draw("same");
  TLine *b8 = new TLine(1.22354, 0 ,1.22354, 850);
  b8->SetLineColor(kRed);
  b8->Draw("same");
  TLine *b9 = new TLine(1.22175, 0 ,1.22175, 850);
  b9->SetLineColor(kRed);
  b9->Draw("same");
//ph

  c0->cd(2);
  h2->Draw();
  h2->GetXaxis()->SetTitle("p [GeV/c]");
  h2->SetTitle("PH");
//th

  c0->cd(3);
  h3->Draw();
  h3->GetXaxis()->SetTitle("p [GeV/c]");
  h3->SetTitle("TH");
//dp

  c0->cd(4);
  h4->Draw();
  h4->GetXaxis()->SetTitle("p [GeV/c]");
  h4->SetTitle("DP");

}




