#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <string>
#include <string.h>

#include "TTree.h"
#include "TFile.h"
#include "TString.h"

#include "TSystem.h"
#include "TH1.h"
#include "TH2.h"
#include "TH3.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TChain.h"
#include "TEllipse.h"
#include "TLine.h"
#include "TMarker.h"
#include "TVector3.h"
#include "TRotation.h"
#include "TMath.h"
#include "TROOT.h"
#include "TF1.h"
#include "TGraph.h"
#include "TGraphErrors.h"
#include "TLatex.h" 
#include "TPolyLine.h" 


#define DEUTERON_MASS 1.875614
#define PROTON_MASS 0.93827
#define RAD2DEG 57.295779
#define DEG2RAD 0.017453293

using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(1111);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);


  gStyle->SetOptStat(1111);

}


void p0root(){

  HallA_style();
  
  Double_t L_gold_p;
  Double_t L_gold_dp;

  

  TChain *t1 =new TChain("T");

  TString filename = Form("./PROJEKT/1461/projekt1461.root");
  t1->Add(filename.Data());
  filename = Form("./PROJEKT/1461/projekt1461_1.root");
  t1->Add(filename.Data());

  assert(t1);
  TChain *t2 =new TChain("T");

  filename = Form("./PROJEKT/1461/projekt1461.root");
  t2->Add(filename.Data());
  filename = Form("./PROJEKT/1461/projekt1461_1.root");
  t2->Add(filename.Data());

  assert(t2);
  
//############################ VARIABLES ############################

  t1->SetBranchAddress( "L.gold.p", &L_gold_p);
  t2->SetBranchAddress( "L.gold.dp", &L_gold_dp);
//############################ Histograms ############################


  TH1F *h1 = new TH1F("h1","h1",200,1.225,1.236);
  TH1F *h2 = new TH1F("h2","h2",200,0.021,0.032);
 

//############################ Analysis p ############################

  int num = t1->GetEntries();
  //num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t1->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h1->Fill(L_gold_p);  

  }

  delete t1; t1=NULL;

	
//############################ Analysis dp ############################

  num = t2->GetEntries();
  //num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t2->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h2->Fill(L_gold_dp);  

  }

  delete t2; t2=NULL;
//########################### OUTPUTFILE###############
	TString filename3=Form("~/PROJEKT/HIST/1461.root");
	TFile *OutputRoot = new TFile( filename3.Data(), "RECREATE");
	h1->Write();
	h2->Write();
	delete OutputRoot; OutputRoot=NULL;

 
}




