#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <string>
#include <string.h>

#include "TTree.h"
#include "TFile.h"
#include "TString.h"

#include "TSystem.h"
#include "TH1.h"
#include "TH2.h"
#include "TH3.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TChain.h"
#include "TEllipse.h"
#include "TLine.h"
#include "TMarker.h"
#include "TVector3.h"
#include "TRotation.h"
#include "TMath.h"
#include "TROOT.h"
#include "TF1.h"
#include "TGraph.h"
#include "TGraphErrors.h"
#include "TLatex.h" 
#include "TPolyLine.h" 


#define DEUTERON_MASS 1.875614
#define PROTON_MASS 0.93827
#define RAD2DEG 57.295779
#define DEG2RAD 0.017453293

using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(0);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);


  gStyle->SetOptStat(0);

}

using namespace std;

int povprecjep0(){
	
  	TString bla1, bla2, bla3, bla4, bla5;
  	double berime1, p00, ep00, p01[100],p02[100], ep01[100], ep02[100];
  	TString filenamedata=Form("PROJEKT/P0/rezultativ2.txt");
  	ifstream data;
  	data.open (filenamedata.Data());
	

	int i=0, k=0;
	if (data.is_open())
  	{
    		while(data>>bla1>>bla2>>berime1>>bla3>>bla4>>p00>>bla5>>ep00)
    		{
	       		cout<<"  "<<berime1<<"   "<<p00<<"  "<<ep00<<endl;
			if(berime1==1456 || berime1==1457 || berime1==1458 || berime1==1459 ) {
				p01[i]=p00;
				ep01[i]=ep00;
				i++;
			}
			if(berime1==1460 || berime1==1461 || berime1==1462 ){
				p02[k]=p00;
				ep02[k]=ep00;
				k++;
 	 		}
		}
        	data.close();
  		}
  	else cout << "Unable to open file/n"; 
	
	double I[100];
	for(int l=0; l<100; l++){
		I[l]=l;
	}


	TCanvas *c0 = new TCanvas("bla","bla",1000,1000);

 	c0->Divide(2,2);
 	c0->cd(1);

 	TGraphErrors *graf1= new TGraphErrors(i, I+1, p01,0 ,ep01);
  	graf1->SetMarkerStyle(20);
  	graf1->SetMarkerColor(3);
	graf1->Draw("AP");
	graf1->SetTitle("1456, 1457, 1458, 1459");
	graf1->GetYaxis()->SetTitle("Mev/c");
   	TF1 *p0fit1 = new TF1("p0fit1","[0]", 0, i+1);
   	//p0fit->SetParLimits(1,1., 2.0);
   	//p0fit->SetParLimits(0,0.7, 2.3);
   	graf1->Fit(p0fit1,"RW");
  
	double chisq1=p0fit1->GetChisquare();
	double ndf1=p0fit1->GetNDF();
	double chisqdf1=chisq1/ndf1;
	cout << "Chisquare: " << chisq1 << "/" << ndf1 << " : " << chisqdf1 << endl;


 	c0->cd(3);

 	TGraphErrors *graf2= new TGraphErrors(k, I+1, p02,0 ,ep02);
  	graf2->SetMarkerStyle(20);
  	graf2->SetMarkerColor(3);
	graf2->Draw("AP");
	graf2->SetTitle("1460, 1461, 1462");
	graf2->GetYaxis()->SetTitle("Mev/c");

   	TF1 *p0fit2 = new TF1("p0fit2","[0]", 0, k+1);
   	//p0fit->SetParLimits(1,1., 2.0);
   	//p0fit->SetParLimits(0,0.7, 2.3);
   	graf2->Fit(p0fit2,"RW");
  
	double chisq2=p0fit2->GetChisquare();
	double ndf2=p0fit2->GetNDF();
	double chisqdf2=chisq2/ndf2;
	cout << "Chisquare: " << chisq2 << "/" << ndf2 << " : " << chisqdf2 << endl;
	c0->cd(2);


	Double_t meanp01 = p0fit1->GetParameter(0);
	Double_t emeanp01 = p0fit1->GetParError(0);
	
	TString beseda1 = Form("p_{0}= %.5f #pm %.5f #frac{MeV}{c}",meanp01, emeanp01);

	TLatex ltext1;
	ltext1.SetTextSize(0.05);
	ltext1.DrawLatex(0.1, 0.2, beseda1.Data());
	


	c0->cd(4);


	Double_t meanp02 = p0fit2->GetParameter(0);
	Double_t emeanp02 = p0fit2->GetParError(0);
	
	TString beseda2 = Form("p_{0}= %.5f #pm %.5f #frac{MeV}{c}",meanp02, emeanp02);

	TLatex ltext2;
	ltext2.SetTextSize(0.05);
	ltext2.DrawLatex(0.1, 0.2, beseda2.Data());

return 0;
}
