#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <string>
#include <string.h>

#include "TTree.h"
#include "TFile.h"
#include "TString.h"

#include "TSystem.h"
#include "TH1.h"
#include "TH2.h"
#include "TH3.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TChain.h"
#include "TEllipse.h"
#include "TLine.h"
#include "TMarker.h"
#include "TVector3.h"
#include "TRotation.h"
#include "TMath.h"
#include "TROOT.h"
#include "TF1.h"
#include "TGraph.h"
#include "TGraphErrors.h"
#include "TLatex.h" 
#include "TPolyLine.h" 


#define DEUTERON_MASS 1.875614
#define PROTON_MASS 0.93827
#define RAD2DEG 57.295779
#define DEG2RAD 0.017453293

using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(0);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);


  gStyle->SetOptStat(0);

}

using namespace std;

int izpis(){
	
  	TCanvas *c0 = new TCanvas("bla","bla",1000,1000);

 	c0->Divide(1,2);
 
	Double_t p01=1.24187, p03=1.19117, p02=1.24055, p04=1.19706 ;
	Double_t emeanp01=0.00841, emeanp03=0.01334, emeanp02=0.00843, emeanp04=0.01317 ;

	c0->cd(1);
	TString beseda1 = Form("p_{01}= %.5f #pm %.5f #frac{MeV}{c}",p01, emeanp01);
	TString beseda2 = Form("p_{02}= %.5f #pm %.5f #frac{MeV}{c}",p02, emeanp02);
	TString beseda7 = Form("p_{0}= 1.238");
	
	TString beseda5 = Form("p_{01}-p_{02}= %.5f ----> %.5f ", p01-p02, (p01-p02)*100/p01);
	TLatex ltext1;
	ltext1.SetTextSize(0.05);
	ltext1.DrawLatex(0.1, 0.8, beseda1.Data());
	TLatex ltext2;
	ltext2.SetTextSize(0.05);
	ltext2.DrawLatex(0.1, 0.6, beseda2.Data());	
	TLatex ltext5;
	ltext5.SetTextSize(0.05);
	ltext5.DrawLatex(0.1, 0.4, beseda5.Data());	
	TLatex ltext7;
	ltext7.SetTextSize(0.05);
	ltext7.DrawLatex(0.1, 0.2, beseda7.Data());			

	c0->cd(2);

	TString beseda3 = Form("p_{01}= %.5f #pm %.5f #frac{MeV}{c}",p03, emeanp03);
	TString beseda4 = Form("p_{02}= %.5f #pm %.5f #frac{MeV}{c}",p04, emeanp04);
	TString beseda6 = Form("p_{02}-p_{01}= %.5f ----> %.5f ", p04-p03, (p04-p03)*100/p01);
	TString beseda8 = Form("p_{0}= 1.2");
	TLatex ltext3;
	ltext3.SetTextSize(0.05);
	ltext3.DrawLatex(0.1, 0.8, beseda3.Data());
	TLatex ltext4;
	ltext4.SetTextSize(0.05);
	ltext4.DrawLatex(0.1, 0.6, beseda4.Data());	
	TLatex ltext6;
	ltext6.SetTextSize(0.05);
	ltext6.DrawLatex(0.1, 0.4, beseda6.Data());	
	TLatex ltext8;
	ltext8.SetTextSize(0.05);
	ltext8.DrawLatex(0.1, 0.2, beseda8.Data());	

return 0;
}
