#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <string>
#include <string.h>

#include "TTree.h"
#include "TFile.h"
#include "TString.h"

#include "TSystem.h"
#include "TH1.h"
#include "TH2.h"
#include "TH3.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TChain.h"
#include "TEllipse.h"
#include "TLine.h"
#include "TMarker.h"
#include "TVector3.h"
#include "TRotation.h"
#include "TMath.h"
#include "TROOT.h"
#include "TF1.h"
#include "TGraph.h"
#include "TGraphErrors.h"
#include "TLatex.h" 
#include "TPolyLine.h" 


#define DEUTERON_MASS 1.875614
#define PROTON_MASS 0.93827
#define RAD2DEG 57.295779
#define DEG2RAD 0.017453293

using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(1111);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);


  gStyle->SetOptStat(1111);

}


void Zgled(){

  HallA_style();
  
  Double_t L_gold_p;


  

  TChain *t1 =new TChain("T");
  Double_t filename;

  TString filename = Form("./PROJEKT/1456/projekt1456.root");
  t1->Add(filename.Data());
  filename = Form("./PROJEKT/1456/projekt1456_1.root");
  t1->Add(filename.Data());

  assert(t1);

//############################ VARIABLES ############################

  t1->SetBranchAddress( "L.gold.p", &L_gold_p);

//############################ Histograms ############################


  TH1F *h = new TH1F("h","h",200,1.22,1.24);
  

//############################ Analysis ############################

  int num = t1->GetEntries();
  //num = 30000;
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t1->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

//################ Primary Cuts ################################


                                                  
//##############################################################  

   h->Fill(L_gold_p);  

  }

  delete t1; t1=NULL;


  //--- Canvas C0
  TCanvas *c0 = new TCanvas("c0","Energije sipanih elektronov",600,600);
  c0->Divide(1,1);
  c0->cd(1);
  h->Draw();
  h->GetXaxis()->SetTitle("p [GeV/c]");
  h->SetTitle("HALL");
  //...TLine
  TLine *b1 = new TLine(1.23898, 0 ,1.23898, 1850);
  b1->SetLineColor(kRed);
  b1->Draw("same");
  TLine *b2 = new TLine(1.2345411, 0 ,1.2345411, 1850);
  b2->SetLineColor(kRed);
  b2->Draw("same");
  TLine *b3 = new TLine(1.2313258, 0 ,1.2313258, 1850);
  b3->SetLineColor(kRed);
  b3->Draw("same");
  TLine *b4 = new TLine(1.228136, 0 ,1.228136, 1850);
  b4->SetLineColor(kRed);
  b4->Draw("same");
  TLine *b5 = new TLine(1.22627, 0 ,1.22627, 1850);
  b5->SetLineColor(kRed);
  b5->Draw("same");
  TLine *b6 = new TLine(1.224897, 0 ,1.224897, 1850);
  b6->SetLineColor(kRed);
  b6->Draw("same");
  TLine *b7 = new TLine(1.22354, 0 ,1.22354, 1850);
  b7->SetLineColor(kRed);
  b7->Draw("same");
  TLine *b8 = new TLine(1.22175, 0 ,1.22175, 1850);
  b8->SetLineColor(kRed);
  b8->Draw("same");
}



